==> kubernetes-model-core-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/ExecActionFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ExecActionFluentImpl<A extends io.fabric8.kubernetes.api.model.ExecActionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ExecActionFluent<A>{
  public ExecActionFluentImpl() {
  }
  public ExecActionFluentImpl(io.fabric8.kubernetes.api.model.ExecAction instance) {
    this.withCommand(instance.getCommand()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> command = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToCommand(java.lang.Integer index,java.lang.String item) {
    if (this.command == null) {this.command = new java.util.ArrayList<java.lang.String>();}
    this.command.add(index, item);
    return (A)this;
  }
  public A setToCommand(java.lang.Integer index,java.lang.String item) {
    if (this.command == null) {this.command = new java.util.ArrayList<java.lang.String>();}
    this.command.set(index, item); return (A)this;
  }
  public A addToCommand(java.lang.String... items) {
    if (this.command == null) {this.command = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.command.add(item);} return (A)this;
  }
  public A addAllToCommand(java.util.Collection<java.lang.String> items) {
    if (this.command == null) {this.command = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.command.add(item);} return (A)this;
  }
  public A removeFromCommand(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.command!= null){ this.command.remove(item);}} return (A)this;
  }
  public A removeAllFromCommand(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.command!= null){ this.command.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getCommand() {
    return this.command;
  }
  public java.lang.String getCommand(java.lang.Integer index) {
    return this.command.get(index);
  }
  public java.lang.String getFirstCommand() {
    return this.command.get(0);
  }
  public java.lang.String getLastCommand() {
    return this.command.get(command.size() - 1);
  }
  public java.lang.String getMatchingCommand(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: command) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingCommand(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: command) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCommand(java.util.List<java.lang.String> command) {
    if (command != null) {this.command = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : command){this.addToCommand(item);}} else { this.command = null;} return (A) this;
  }
  public A withCommand(java.lang.String... command) {
    if (this.command != null) {this.command.clear();}
    if (command != null) {for (java.lang.String item :command){ this.addToCommand(item);}} return (A) this;
  }
  public java.lang.Boolean hasCommand() {
    return command != null && !command.isEmpty();
  }
  public A addNewCommand(java.lang.String arg0) {
    return (A)addToCommand(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExecActionFluentImpl that = (ExecActionFluentImpl) o;
    if (command != null ? !command.equals(that.command) :that.command != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(command,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/ExecActionFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ExecActionFluentImpl<A extends io.fabric8.kubernetes.api.model.ExecActionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ExecActionFluent<A>{
  public ExecActionFluentImpl() {
  }
  public ExecActionFluentImpl(io.fabric8.kubernetes.api.model.ExecAction instance) {
    this.withCommand(instance.getCommand()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> command = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToCommand(java.lang.Integer index,java.lang.String item) {
    if (this.command == null) {this.command = new java.util.ArrayList<java.lang.String>();}
    this.command.add(index, item);
    return (A)this;
  }
  public A setToCommand(java.lang.Integer index,java.lang.String item) {
    if (this.command == null) {this.command = new java.util.ArrayList<java.lang.String>();}
    this.command.set(index, item); return (A)this;
  }
  public A addToCommand(java.lang.String... items) {
    if (this.command == null) {this.command = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.command.add(item);} return (A)this;
  }
  public A addAllToCommand(java.util.Collection<java.lang.String> items) {
    if (this.command == null) {this.command = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.command.add(item);} return (A)this;
  }
  public A removeFromCommand(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.command!= null){ this.command.remove(item);}} return (A)this;
  }
  public A removeAllFromCommand(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.command!= null){ this.command.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getCommand() {
    return this.command;
  }
  public java.lang.String getCommand(java.lang.Integer index) {
    return this.command.get(index);
  }
  public java.lang.String getFirstCommand() {
    return this.command.get(0);
  }
  public java.lang.String getLastCommand() {
    return this.command.get(command.size() - 1);
  }
  public java.lang.String getMatchingCommand(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: command) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingCommand(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: command) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCommand(java.util.List<java.lang.String> command) {
    if (command != null) {this.command = new java.util.ArrayList(); for (java.lang.String item : command){this.addToCommand(item);}} else { this.command = null;} return (A) this;
  }
  public A withCommand(java.lang.String... command) {
    if (this.command != null) {this.command.clear();}
    if (command != null) {for (java.lang.String item :command){ this.addToCommand(item);}} return (A) this;
  }
  public java.lang.Boolean hasCommand() {
    return command != null && !command.isEmpty();
  }
  public A addNewCommand(java.lang.String arg0) {
    return (A)addToCommand(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExecActionFluentImpl that = (ExecActionFluentImpl) o;
    if (command != null ? !command.equals(that.command) :that.command != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(command,  additionalProperties,  super.hashCode());
  }
  
}
